+++
title = "Slug Front-matter"
slug = "this-is-how-i-want-to-name-this-link"
tags = ["front-matter", "slug"]
draft = false
+++

By default, a page's _slug_ is the name of the content file (sans
extension). So in this case, it would have been
`slug-front-matter`. But that slug is overridden using the specified
`slug` in the front-matter: `this-is-how-i-want-to-name-this-link`.
